#
# spec file for package python-pytest-socket
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-socket
Version:        0.7.0
Release:        1.5
Summary:        Pytest Plugin to disable socket calls
License:        MIT
URL:            https://github.com/miketheman/pytest-socket
Source:         https://files.pythonhosted.org/packages/source/p/pytest-socket/pytest_socket-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pytest >= 3.6.3
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest >= 3.6.3}
# /SECTION
%python_subpackages

%description
A plugin to use with Pytest to disable or restrict socket calls during
tests to ensure network calls are prevented.

%prep
%setup -q -n pytest_socket-%{version}
touch tests/__init__.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONPATH=$PWD/tests
# Most tests require a network connection, let's check basic function
%pytest -k 'test_disable_via or test_global_disable_via'

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/pytest_socket.py
%pycache_only %{python_sitelib}/__pycache__/pytest_socket*.pyc
%{python_sitelib}/pytest_socket-%{version}.dist-info

%changelog
* Fri Sep 20 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.7.0:
  * Enhancements:
    + Force enable socket CLI flag #186
    + Use getaddrinfo() instead of gethostbyname() #209
    + Allow both Hosts via IP and Name #275
  * Changes:
    + Removed support for Python 3.7 and older.
    + Dependency updates
    + Development updates
    + Testing updates
    + Emit license and readme for source distribution #233
- Update description and summary.
- Switch to pyproject macros.
- Run a small part of the test suite to check basic functionality.
- No more greedy globs in %%files.
* Tue May  9 2023 Dirk Müller <dmueller@suse.com>
- update to 0.6.0:
  * Add Change Log project URL
  * test: update httpbin commit hash
  * Upgrade CodeSee workflow to version 2
  * fix: don't break on doctests
  * docs: Fix syntax for setup.cfg
  * Fix pytest-socket raises IndexError with httpx
  * test: move the reenable fixture to conftest
  * Switch to poetry-core
  * Handle `family` passed as keyword argument
  * refactor: consolidate global options to config
  * test: replace pytest-flake8 with pre-commit
  * refactor/fix: move logic into setup phase and correct order
  * test: add test module for combinations
  * fix: test allow_hosts for unix sockets
  * test: move unix decorator to conftest
  * test: randomize test order
  * test: replace coverage command
  * refactor: replace .format with f-strings
  * lint: apply black
  * Enable Unix sockets selectively with --allow-unix-socket
  * Test refactor, add CodeQL scanning
  * Correctly subclass socket.socket
  * Add testing against Python 3.9, Dropped testing against
    Python 3.5
  * Doc updates
  * Avoid changing the type of `socket.socket` to function.
  * Sourcery Starbot ⭐ refactored miketheman/pytest-socket
  * Don't block unix sockets
  * docs: add details on fixture scope
  * chore: replace rst with markdown
  * test: add testing for some async frameworks
* Tue Jun  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.5:
  * Fix bug in marker evaluation #42
  * Refactor tests for clarity
* Tue Apr 14 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.4:
  * Drop support for unsupported versions of Python #23
  * Convert toolchain from pip/tox/twine to poetry
  * Replace TravisCI and Appveyor with GitHub Actions #36
  * Update for correct test output #31
  * Add renovatebot for dependecy updates #26
* Tue Jul 23 2019 Todd R <toddrme2178@gmail.com>
- Initial version
